#
# spec file for package kdenlive
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define mlt_version 6.10.0
%define melt_path %(pkg-config --variable=meltbin mlt-framework)
%define mlt_soname %(pkg-config --variable=moduledir mlt-framework | sed 's/.*-\\([0-9]\\+\\)/\\1/')
%define kf5_version 5.26.0
# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %define _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           kdenlive
Version:        18.12.3
Release:        2.1
Summary:        Non-linear video editor
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            http://www.kdenlive.org/
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  desktop-file-utils
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  karchive-devel
BuildRequires:  kconfig-devel
BuildRequires:  kconfigwidgets-devel
BuildRequires:  kcoreaddons-devel
BuildRequires:  kcrash-devel
BuildRequires:  kdbusaddons-devel
BuildRequires:  kdoctools-devel
BuildRequires:  kguiaddons-devel
BuildRequires:  kiconthemes-devel
BuildRequires:  kio-devel
BuildRequires:  knewstuff-devel
BuildRequires:  knotifications-devel
BuildRequires:  knotifyconfig-devel
BuildRequires:  kplotting-devel
BuildRequires:  ktextwidgets-devel
BuildRequires:  kwidgetsaddons-devel
BuildRequires:  kxmlgui-devel
BuildRequires:  libmlt-devel
BuildRequires:  pkgconfig
BuildRequires:  shared-mime-info
BuildRequires:  cmake(KF5FileMetaData)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(mlt++) >= %{mlt_version}
BuildRequires:  pkgconfig(mlt-framework) >= %{mlt_version}
BuildRequires:  pkgconfig(x11)
# Waiting for the day all libraries have versioned symbols...
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libmlt++.so) --qf '%%{NAME}') >= %{mlt_version}
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libmlt.so) --qf '%%{NAME}') >= %{mlt_version}
# It requires the profiles
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libmlt.so) --qf '%%{NAME}')-data
# Without a few of the plugins it crashes on start
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libmlt.so) --qf '%%{NAME}')-modules
Requires:       %{melt_path}
# It doesn't start without it (boo#994649)
Requires:       libqt5-qtquickcontrols
Recommends:     %{_bindir}/dvdauthor
Recommends:     %{_bindir}/dvgrab
Recommends:     %{_bindir}/ffmpeg
Recommends:     %{_bindir}/ffplay
Recommends:     %{_bindir}/genisoimage
Recommends:     frei0r-plugins
Recommends:     libv4l
Recommends:     mlt(%{mlt_soname})(avformat)
Obsoletes:      kdenlive5 < %{version}
Provides:       kdenlive5 = %{version}
%if %{with lang}
Recommends:     %{name}-lang
%endif

%description
Kdenlive is a non-linear video editor for GNU/Linux and FreeBSD, which supports
DV, AVCHD (experimental support) and HDV editing. Kdenlive relies on several
other open source projects, such as FFmpeg and the MLT video framework. It was
designed to answer all needs, from basic video editing to semi-professional
work.

%if %{with lang}
%lang_package
%endif

%prep
%setup -q

%build
%cmake_kf5 -d build
%make_jobs

%install
%kf5_makeinstall -C build
%if %{with lang}
  %find_lang %{name} --with-man --all-name
  %{kf5_find_htmldocs}
%endif
%fdupes -s %{buildroot}
rm -fr %{buildroot}%{_datadir}/doc/Kdenlive

%post
%icon_theme_cache_post
%mime_database_post
%desktop_database_post

%postun
%desktop_database_postun
%mime_database_postun
%icon_theme_cache_postun

%files
%defattr(0644,root,root,0755)
%attr(0755,-,-) %{_bindir}/%{name}
%attr(0755,-,-) %{_bindir}/%{name}_render
%license COPYING
%doc AUTHORS README
%(config) %{_kf5_configdir}/*.knsrc
%(config) %{_kf5_configdir}/kdenlive.categories
%dir %{_kf5_configkcfgdir}
%doc %lang(en) %{_kf5_htmldir}/en/kdenlive/
%{_kf5_applicationsdir}/org.kde.kdenlive.desktop
%{_kf5_appstreamdir}/
%{_kf5_configkcfgdir}/kdenlivesettings.kcfg
%{_kf5_iconsdir}/hicolor/*/*/*
%{_kf5_kxmlguidir}/kdenlive/
%{_kf5_mandir}/man1/*
%{_kf5_plugindir}/mltpreview.so
%{_kf5_servicesdir}/mltpreview.desktop
%{_kf5_sharedir}/kdenlive/
%{_kf5_sharedir}/knotifications5/kdenlive.notifyrc
%{_kf5_sharedir}/mime/packages/*

%if %{with lang}
%files lang -f %{name}.lang
%license COPYING*
%endif

%changelog
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * Update copyright year also.
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * Fix empty warning dialog on missing font in project BUG: 401903 (kde#401903)
  * Fix bin item description cannot be edited if it contains zone subclips BUG: 402817 (kde#402817)
  * Fix screengrab with audio broken
  * Move Gain effect to "Audio correction" category Patch by Juku Trump https://phabricator.kde.org/D17968
  * ci: enable freebsd build
  * QtScript is not used anymore
  * ci: add recipe for gitlab CI
  * Fix incorrect color theme correction for AppImages Related to #2
  * Fix color theme lost on AppImage
  * Update AppData app version
  * Fix bin/melt.exe & libmlt* loading on Windows
  * necessary OpenGL headers are provided by Qt
  * Fix keyframes import
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * Fix crash on image sequence import
  * Backport fix for titler text gradient
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Add donation url to appdata
  * Fix minor EBN issues and typos
  * Fix play/pause on Windows
  * Sync quickstart manual with UserBase
  * Install doc files
  * Make it compiles when we use QT_NO_NARROWING_CONVERSIONS_IN_CONNECT
  * Fix minor EBN issues
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * Fix finding MLT data in build-time specified path
  * Fix play/pause on Windows
  * Try catching application initialization crashes
  * Fix MinGW build script misses
  * Backport some Shotcut GLwidget updates
  * Fix MinGW build
  * Install doc files
  * build scripts for Linux & Windows
  * Backport packaging scripts
  * Fix MinGW build
  * Backport fix for incorrect bin rename CCBUG: 368206
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * Improve missing luma detection (region transition) - fixes project crash
  * Home/End now also seek in clip monitor
  * Update AppData for upcoming release
  * Windows crash reports
  * Update authors
  * Fix double clicking a title clip in bin tries to rename instead of opening the title dialog
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Fix proxy creation not restarting when changing a property while creating proxy
  * Prepare AppData for next release
  * Fix clip proxy on autorotate BUG: 397762 (kde#397762)
  * Fix effects parameters parsing
  * Give priority to local effects over system ones
  * Access to MLT debug info (command line option)
  * Fix OffScreenSurface creation in GUI thread
  * Increase max unzoom level, uniform zoom factor
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Fix custom lift/gamma/gain displaying wrong UI (kde#364127)
  * Updated appdata
  * Fix possible crash in monitor restart
  * Reduce minimum profile widget height to make dialog fit in screen (kde#384511)
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Require MLT 6.10 (to avoid the incompatible 6.8)
  * Fix compile warning
  * Backport KF5 Purpose share feature
  * Backport fix for incorrect gap in texts
  * Update readme with correct infos
  * Scale TitleTemplateDialog preview with the window
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * None
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * Don't display Wizard on every AppImage startup
  * Fix message extraction
  * Prepare for 18.04.2 release
  * Rename mime type file to make flatpak happy Differential Revision: https://phabricator.kde.org/D13143
  * Fix crash with MLT 6.8.0 and some keyfameable parameters (box blur)
  * Consistent behavior for mouse wheel: down goes forward, up goes backwards BUG: 394341 (kde#394341)
  * Update readme with correct infos
- Dropped patches, now upstream:
  * fix-crash-with-mlt-6.8.0.patch
* Wed May 23 2018 wbauer@tmo.at
- Add fix-crash-with-mlt-6.8.0.patch to fix crashes with mlt>6.6.0
  when using effects with some keyframeable parameters (kde#394275)
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * update monitor safezone overlay
  * Update appdata version
  * Improve titler default background color
  * Fix build with Qt 5.11_beta3 (dropping qt5_use_modules)
  * Only check color theme on first run, not each time the Wizard is called BUG:388274 (kde#388274)
* Thu Apr 19 2018 wbauer@tmo.at
- Raise minimum mlt version to 6.6.0
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * Fix luma files lost when opening project with AppImage
  * Stop looking for DVD related apps on startup
  * Update AppData version for comming release
  * Scale TitleTemplateDialog preview with the window
  * Fix rendering using custom folder when not requested BUG: 387135 (kde#387135)
  * Fix double separator in project/capture folder CCBUG: 387135
  * Fix possibly wrong message on moving project folder
  * Fix regression breaking fades and other effects on resize
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Fix lowres icons on highdpi patch by Andrew Crouthamel BUG: 390104 (kde#390104)
  * Fix crash when initializing offscreen surface in GLWidget
  * Move knsrc files in Qt resource so we find them without install BUG: 392201 (kde#392201)
  * Fix build with Qt 5.11 (missing headers)
  * Fix project settings vertical scrollbar on open Differential Revision: https://phabricator.kde.org/D10449
  * Update minimum MLT version to latest release (fixes audio mix problem)
  * Fix AppImage screenshot BUG: 388676 (kde#388676)
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * Use KAboutData::setDesktopFileName instead of QGuiApplication version.
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Fix compatibility with MLT >= 6.6.0
  * Fix build with Qt 5.6
  * Fix backwards seeking not stoping when reaching clip start
  * Add release version number to AppData
  * Don't query available widget styles on each startup
  * Fix webM encoding (auto replace vorbis by libvorbis if installed) BUG: 388503 (kde#388503)
- Dropped patches, now upstream:
  * fix-build-with-Qt5.6.patch
* Wed Jan 17 2018 wbauer@tmo.at
- Escape the usage of %%{NAME} when calling out to rpm.
  RPM 4.14 has %%{NAME} defined as 'the main package's name'.
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * Fix translation install
* Wed Jan  3 2018 wbauer@tmo.at
- Add fix-build-with-Qt5.6.patch to make it compile on standard
  Leap 42.3
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * remove useless audio bitrate on pcm proxy encoding
  * Update proxy profiles
  * Make sure playlist proxies have an even height
  * Fix crash on playlists concurrent jobs using library clips CCBUG: 386616
  * Timeline preview fixes: Don't invalidate on expand/collapse effect, invalidate on master clip edit
  * Don't restart clip if trying to play backwards from clip monitor end
  * Use smaller size for image proxies BUG: 353577 (kde#353577)
  * Fix playing backwards forwards one second BUG: 375634 (kde#375634)
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * None
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Fix extension in transcode file dialog
  * Sort clip zones by position instead of name
  * Set a proper desktop file name to fix an icon under Wayland.
  * FreeBSD does not have sys/asm.h -- for what is this include needed on linux?
  * doc: fix option (qwindowtitle instead of caption)
  * Fix terminology: mimetype(s) -> MIME type(s)
  * Fix UI string: Control Center -> System Settings
  * Const'ify code
  * fix import image sequence
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * Set a proper desktop file name to fix an icon under Wayland.
  * Sort clip zones by position instead of name
  * Fix melt.exe finding on windows
  * Revert "Windows: terminate KDE session on window close"
  * Make KCrash optional
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * Fix autosave : workaround KAutoSaveFile bug with non ascii chars
  * Get ready for transform centered rotation
  * Fix keyframes unseekable on bin effects
  * Fix lift to handle negative values (requires latest MLT version)
  * Prefer SDL2 to SDL1 (dropped by FFmpeg and so MLT)
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * Remember last selected title template CCBUG: 384340
  * Fix proxy error (height not multiple of 2) BUG: 384345 (kde#384345)
  * Fix extract frame from bin exporting lower than source image
  * Fix visibility check of tracks in multitrack-view Differential Revision: https://phabricator.kde.org/D7670
  * Allow disabling autosave until we improve it BUG: 384197 (kde#384197)
  * Windows: find Kdenlive lumas (kde#375337)
  * Windows: terminate KDE session on window close (kde#380854)
  * Windows: always use bundled MLT (kde#380036)
  * Remove project profiles sharing (knsrc) (kde#383238)
  * Gardening: fix GCC warnings (8)
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * Fix crash on importing multistream clip BUG: 381584 (kde#381584)
  * Fix crash when creating proxies - real issue not yet fixed CCBUG: 381738
  * fix compile (gcc7) (kde#379688)
  * show info on MLT found by CMake
  * non-portable flag, let build system handle it
  * Windows icons are delivered in icontheme.rcc
  * Fix compilation
  * Fix custom profile not found on creation
  * Fix loop zone BUG: 378813 BUG: 381146 (kde#378813, kde#381146)
- Remove patches, now upstream:
  * gcc7-fixes.patch
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * Forgot this file in previous commit :(
  * Fix crash changing title font for 2nd time (kde#379606)
  * more Windows rendering fixes
  * Fix init of geometryWidget
* Mon May 29 2017 wbauer@tmo.at
- Add gcc7-fixes.patch to fix build with gcc7 (boo#1041232)
* Tue May 23 2017 wbauer@tmo.at
- Only use the %%kf5_find_htmldocs macro on Leap 42.3 and higher,
  this should fix the build for 42.2 on Packman
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Fix title clip duration cannot be changed BUG: 379582 (kde#379582)
  * Allow passing pre-parameters using "-i" to specify where the input file name should go in ffmpeg parameters Should work in proxy and transcoding, for example: -vaapi_device /dev/dri/renderD128 -hwaccel vaapi -hwaccel_output_format vaapi -i -an -c:v dnxhd Will insert source file name after "-i". CCBUG: 378832
  * Fixed off-by-one errors in fft-based cross-correlation computations Patch by raphaelm Differential Revision: https://phabricator.kde.org/D5454
  * Don't show color theme configuration option unavailable on Windows (kde#375723)
  * Fix temp path on Windows (kde#375717)
  * Fix MLT doc link (kde#375316)
  * Fix script export & QScript header left
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * Don't show color theme configuration option unavailable on Windows
  * Fix temp path on Windows
  * Fix MLT doc link
  * Fix script export & QScript header left
  * Fix glitch on pause and does not play last second of project BUG: 371762 (kde#371762)
  * remove QScript dependency
  * Fix render scripts on Windows: generate .bat files
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * Fix possible crash on rendering with "play after render" option
  * Images also use qimage producer
  * fix Windows build with C++ threads
  * Fix some effects incorrectly initialized on tracks BUG: 378071
  * Remove beta message in preparation of release
  * Fix locked ratio scaling
  * Fix archived project wrong path and missing images/slideshows CCBUG: 377999 CCBUG: 378000
  * More clever ratio locking in effect/transition
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar 23 2017 wbauer@tmo.at
- Don't generate the oxygen icon theme cache on (un)installation,
  no oxygen icons are getting installed
- Drop use-mlt_datadir.patch, no longer necessary since a while
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * Fix crash & corruption on dragging multiple clips in timeline, fix thread warning on monitor refresh
  * Avoid possible profile corruption with xml producer CCBUG: 371189
  * Avoid relying on xml to clone a clip.
  * src/dvdwizard/dvdwizardmenu.cpp: do not show "grid" in output (kde#377256)
  * src/dvdwizard/dvdwizard.cpp: fix file loading in slotLoad (kde#377254)
  * Fix Render Widget's file dialog not working correctly (requires KDE Frameworks >= 5.33) BUG: 371685 (kde#371685)
  * Fix render job duration when past midnight BUG: 372370 (kde#372370)
  * Fix Bin Effect reset BUG: 376494 (kde#376494)
  * Fix unnecessary refresh of tools when selecting titler item
  * Fix fadeouts re-appearing on clip cut+resize
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Mon Jan 30 2017 guoyunhebrave@gmail.com
- Add frei0r-plugins recommends
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
- Drop the full url for the source file. This is causing issues
  when submitting non-released versions and causes false declines
  from factory-auto
* Thu Dec  8 2016 lbeltrame@kde.org
- Fix source URL
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 19 2016 wbauer@tmo.at
- Require libqt5-qtquickcontrols, it doesn't start without it (boo#994649)
- Minimum required mlt version is 6.0.0 now
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Sat Jul  2 2016 fvogt@suse.com
- Update required MLT version to 0.9.8 to avoid failing builds
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sun Feb  7 2016 wbauer@tmo.at
- Add BuildRequires: pkgconfig(libv4l2) to fix boo#959174
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.2
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
- Drop upstreamed patches:
  * kdenlive-0.9.10-no_avformat.patch
- Renamed and adjusted patch
  * use-mlt_datadir.patch
* Thu Oct 16 2014 nico.kruber@gmail.com
- Update to 0.9.10
  + handle VBR encoding profiles, and use it!
  + video stabilizer: added new "vid.stab", removed older ones
  + environment variable MLT_PREFIX overrides profiles & melt path
  + several fixes for high dpi screens
  + change proxy profile, obsolete with libav
  + add SVG to image formats for slideshows
  + restore project render bitrate (#3326)
  + show proxy name in clipproperties
  + add link to MLT doc in render edit dialog (#3355)
  + update maximum track height (#3241)
  + resize render path box (#3300)
  + change transition settings layout (#3336)
  + heat colormap in spectrogram (#3142)
  + fix clip monitor switch on proxy creation end (#3308)
  + fix clip jobs (stabilize) operating on proxies (#3337)
  + fix timeline corruption by clip resize end + zoom change
  + fix title clip duration not taken into account (#3309)
  + fix timeline thumbs flicker when fully zoomed (#3247)
  + fix thumbnailer aspect ratio
  + fix fades for split audio (#3323)
  + fix transcoding (#3334)
  + fix 'Clip in Timeline' when project monitor is inactive (#3261)
  + fix audio analysis (use dynamic memory instead of stack)
  + fix render end notification
  + fix render timecode overlay (#3260)
  + set tooltip for monitor pause button (#3256)
  + fix slideshow clips adding 1 frame (#3289)
  + fix archive project icon (#3325)
  + fix compilation on armhf (#3345)
  + don't allow creating keyframes for "fixed" filters (#2956)
  + re-enable compilation on KDE < 4.5 (squeeze) (#3319)
  + re-enable Clip menu (fix bug #3347)
  + fix screen recording failure (#3358)
  + fix crash detected with undo/redo (bug #3240)
  + fix crash cutting group on a clip edge (#3312, #3350)
  + fix crash on image sequence (#3331)
  + fix crash in tracks config editor (#3367)
  + fix crash on audiofiles
  + fix crash on opening project file with images
  + fix warnings from static analyzers (cppcheck, krazy)
  + sort source files, easier to understand (for new developpers)
- Update kdenlive-0.9.2-mlt_datadir.patch to
  kdenlive-0.9.10-mlt_datadir.patch
- Update kdenlive-0.9.2-no_avformat.patch to
  kdenlive-0.9.10-no_avformat.patch
* Wed Jul  2 2014 fisiu@opensuse.org
- Build all translations.
* Wed May 21 2014 dap.darkness@gmail.com
- Update to 0.9.8
  + Fades: timeline shortcut now applies to video on clips
    containing video and audio;
  + Copy proxies with 'move project';
  + Remove the MLT processing threads option that never really
    worked;
  + Clean encoding profiles using MLT presets and profiles;
  + Support a custom suffix for FFmpeg binaries (mostly for
    packagers);
  + Make audio align work asynchronously;
  + Add support for JogShuttle on newer systems, make shuttle
    device selection more straightforward, add ProV2 keys;
  + Fix warnings from gcc, cppcheck, clang, scan-build: fixes
    many crashs & leaks;
  + Code cleanup (use const ref, fix includes, mem leaks,
    optimize...);
  + Fix keyframing messed up for some effects;
  + Fix timeline corruption when trying to move clip before 0;
  + Fix crash when closing title widget;
  + Fix thumbnails for image clips in timeline;
  + Fix crash on quick undo/redo (#3240);
  + Fix multithreading (#3186);
  + Fix some problems with transitions keyframes;
  + Fix scopes (#3052).
- Updated kdenlive-0.9.2-mlt_datadir.patch &
  kdenlive-0.9.2-no_avformat.patch.
* Sun Apr  7 2013 hrvoje.senjan@gmail.com
- Update to 0.9.6
  + Fix keyframes when cutting a clip / undoing a clip cut
  + Warn before overwriting .mlt stabilized file
  + Fix monitor confusion (clip monitor sometimes playing timeline)
  + Fix the Mono to Stereo effect UI
  + Fix proxy of playlist having wrong aspect ratio in some locales
  + Fix transition widget not correctly updated when resizing a
    transition
  + Fix DVD chapters broken when using an intro movie
  + Fix error message (No matching profile) poping up in render
    widget when everything was ok
  + Fix clip keyframes not showing on project load
  + Fix bug when moving guide (was not moving to the correct place)
  + Fix project corruption (wrong character) caused by some clip's
    metadata
  + Fix possible crash on track deletion
  + Fix timeline corruption when using spacer tool or overwrite edit
    mode
  + Fix possible crash when editing speed effect
  + Fix transition losing all its properties when moved
  + Fix crash when pressing del when editing animation in title
    widget
  + Fix crash when doing quick clip resize
  + Fix corruption when groups where overlapping
  + Fix corruption when adding a title clip where a transition already
    existed
  + Fix timeline preview corruption with some transitions
* Tue Feb  5 2013 reddwarf@opensuse.org
- Add missing BR: pkgconfig(libv4l2)
* Wed Jan 30 2013 reddwarf@opensuse.org
- Do not recommend recordmydesktop. It's not used any more.
- Update the minimum mlt version
- Reenable V4L support. The legal problem has been fixed.
* Wed Jan 30 2013 nico.kruber@gmail.com
- Update to 0.9.4
  + Rewritten DVD Wizard
  + Improved clip markers
  + Rewritten Screen Capture
  + Support for multiple streams clips
  + Clip analysis feature
  + Stability and Performance improvements
  - 8 features introduced
  - 124 bugs fixed
* Fri Nov 30 2012 reddwarf@opensuse.org
- Make it work with versioned melt binaries
- Add kdenlive-0.9.2-no_avformat.patch to support systems without
  the avformat plugin
* Thu Aug 16 2012 reddwarf@opensuse.org
- Recommend a package with the avformat module
* Mon Aug 13 2012 reddwarf@opensuse.org
- Require libmltX-modules and libmltX-data
* Sun Aug 12 2012 reddwarf@opensuse.org
- Add kdenlive-0.9.2-mlt_datadir.patch to use the correct MLT data
  dir by default
* Fri Jun  1 2012 reddwarf@opensuse.org
- Disable V4L support (bnc#765082). GPL-2.0 only, incompatible
  with GPL-3.0+ parts.
* Thu May 31 2012 reddwarf@opensuse.org
- Update to 0.9.2
  + Fix freeze when reloading previously missing clip
  + Fade effects lost when moving / resizing clip
  + Undoing change in clip crop start breaking clip
  + Make disabling of track effects possible
  + Fix slideshow clips not working
  + Fix crash on composite transition
  + Fix crash when opening stop motion widget
  + Fix rendering of projects created in another locale
  + Fix Firewire capture
* Tue May 15 2012 reddwarf@opensuse.org
- Update to 0.9
  * Improved effects workflow
  * Automatic audio alignment
  * Easy import of online resources
  * Usability improvements
  - Recording can now be monitored through the audio and color
    scopes, audio normalization can analyse audio for better
    results
  - Allow audio only recording
  - Clips can be sorted by date
  - New effects from MLT / frei0r: video stabilizers,
    IIR Blur, etc
  - Offline editing (Backup the project with proxy clips only to
    work on less powerful computers)
  * Read the ChangeLog file for a more complete list of changes
- Add %%icon_theme_cache_post and %%desktop_database_post macros and
  its dependencies as BuildRequires
- Update the BuildRequires
- Updates source tag with new URL
- Recommend genisoimage instead of mkisofs
* Fri May  4 2012 reddwarf@opensuse.org
- Change license from GPL-2.0+ to GPL-2.0 (bnc#760651)
* Mon Feb 27 2012 saschpe@suse.de
- Set SPDX-style license
* Sun Aug 23 2009 reddwarf@opensuse.org
- Initial package
